Event API
=========

.. currentmodule:: wdom.event

.. autoclass:: wdom.event.Event
   :members:

.. autofunction:: wdom.event.create_event

.. autoclass:: wdom.event.EventListener
   :members:

.. autoclass:: wdom.event.EventTarget
   :members:
